@@ -35,18 +35,32 @@
 #include "../config.h"
 #include "../dataClassify.h"
 #include "../errHand.h"
+#include "../main.h"
 #include "../network.h"
 #include "../printtext.h"
 #include "../strHand.h"
 
 #include "services.h"
+#include "squery.h"
+
+static stringarray_t cs_cmds = {
+//lint -e786
+	cs_cmds_macro(--),
+//lint +e786
+};
+
+static stringarray_t ns_cmds = {
+//lint -e786
+	ns_cmds_macro(--),
+//lint +e786
+};
 
 class irc_service_cmd {
 	std::string	srv_host;
 	std::string	msg;
 
 public:
-	explicit irc_service_cmd(const char *);
+	explicit irc_service_cmd(CSTRING);
 
 	const std::string &
 	get_srv_host(void) const
@@ -54,18 +68,18 @@ public:
 		return this->srv_host;
 	}
 
-	const char *
+	CSTRING
 	get_msg(void) const
 	{
 		return this->msg.c_str();
 	}
 };
 
-irc_service_cmd::irc_service_cmd(const char *data)
+irc_service_cmd::irc_service_cmd(CSTRING data)
 {
-	char *dcopy;
-	char *last = const_cast<char *>("");
-	char *token1, *token2;
+	STRING	 dcopy;
+	STRING	 token1, token2;
+	char	*last = const_cast<char *>("");
 
 	if (strings_match(data, ""))
 		throw std::runtime_error("no data");
@@ -84,8 +98,8 @@ irc_service_cmd::irc_service_cmd(const char *data)
 }
 
 static void
-run_command(const char *slashcmd, const char *srv_name,
-    const char *host_setting, const char *data)
+run_command(CSTRING slashcmd, CSTRING srv_name, CSTRING host_setting,
+    CSTRING data)
 {
 	try {
 		irc_service_cmd sc(data);
@@ -104,10 +118,7 @@ run_command(const char *slashcmd, const char *srv_name,
 				throw std::runtime_error("cannot send");
 		}
 	} catch (const std::runtime_error &e) {
-		std::string str(slashcmd);
-
-		(void) str.append(": ").append(e.what());
-		printtext_print("err", "%s", str.c_str());
+		printtext_print("err", "%s: %s", slashcmd, e.what());
 
 		if (strings_match(e.what(), "cannot send")) {
 			err_log(ENOTCONN, "%s", slashcmd);
@@ -120,7 +131,7 @@ run_command(const char *slashcmd, const char *srv_name,
  * usage: /chanserv <[service hostname | --]> <command> [...]
  */
 void
-cmd_chanserv(const char *data)
+cmd_chanserv(CSTRING data)
 {
 	run_command("/chanserv", "ChanServ", "chanserv_host", data);
 }
@@ -129,7 +140,7 @@ cmd_chanserv(const char *data)
  * usage: /nickserv <[service hostname | --]> <command> [...]
  */
 void
-cmd_nickserv(const char *data)
+cmd_nickserv(CSTRING data)
 {
 	run_command("/nickserv", "NickServ", "nickserv_host", data);
 }
@@ -138,7 +149,61 @@ cmd_nickserv(const char *data)
  * usage: /qbot <[service hostname | --]> <command> [...]
  */
 void
-cmd_qbot(const char *data)
+cmd_qbot(CSTRING data)
 {
 	run_command("/qbot", "Q", "qbot_host", data);
 }
+
+static void
+add_cmd(PTEXTBUF matches, CSTRING str)
+{
+	if (textBuf_size(matches) != 0) {
+		if ((errno = textBuf_ins_next(matches, textBuf_tail(matches),
+		    str, -1)) != 0)
+			err_sys("%s: textBuf_ins_next", __func__);
+	} else {
+		if ((errno = textBuf_ins_next(matches, NULL, str, -1)) != 0)
+			err_sys("%s: textBuf_ins_next", __func__);
+	}
+}
+
+static PTEXTBUF
+get_list(CSTRING search_var, stringarray_t array, const size_t size)
+{
+	PTEXTBUF matches = textBuf_new();
+
+	for (size_t i = 0; i < size; i++) {
+		CSTRING cmd = array[i];
+
+		if (!strncmp(search_var, cmd, strlen(search_var)))
+			add_cmd(matches, cmd);
+	}
+
+	return matches;
+}
+
+PTEXTBUF
+get_list_of_matching_cs_cmds(CSTRING search_var)
+{
+	PTEXTBUF matches = get_list(search_var, cs_cmds, ARRAY_SIZE(cs_cmds));
+
+	if (textBuf_size(matches) == 0) {
+		textBuf_destroy(matches);
+		return NULL;
+	}
+
+	return matches;
+}
+
+PTEXTBUF
+get_list_of_matching_ns_cmds(CSTRING search_var)
+{
+	PTEXTBUF matches = get_list(search_var, ns_cmds, ARRAY_SIZE(ns_cmds));
+
+	if (textBuf_size(matches) == 0) {
+		textBuf_destroy(matches);
+		return NULL;
+	}
+
+	return matches;
+}
