@@ -63,18 +63,20 @@ static stringarray_t theme_cmds = {
 	"install bx",
 	"install nano",
 	"install superkod",
+	"install weechat",
 	"list-remote",
 	"set ",
 	"set bx",
 	"set nano",
 	"set superkod",
+	"set weechat",
 };
 
 static THEME_INFO theme_info_array[MAX_NO_THEMES];
 
-static void free_theme_info(PTHEME_INFO) PTR_ARGS_NONNULL;
-static void install_theme(const char *) PTR_ARGS_NONNULL;
-static void set_theme(const char *) PTR_ARGS_NONNULL;
+static void free_theme_info(PTHEME_INFO) NONNULL;
+static void install_theme(const char *) NONNULL;
+static void set_theme(const char *) NONNULL;
 
 static bool
 is_instruction_ok(const char *instruction)
@@ -491,12 +493,13 @@ cmd_theme(const char *data)
 	}
 
 	if (strings_match(instruction, "install")) {
-		if (theme_is_in_db(name))
+		if (isValid(name) && theme_is_in_db(name))
 			install_theme(name);
 	} else if (strings_match(instruction, "list-remote")) {
 		list_remote();
 	} else if (strings_match(instruction, "set")) {
-		if (strings_match(name, "default") || theme_is_in_db(name))
+		if (isValid(name) && (strings_match(name, "default") ||
+		    theme_is_in_db(name)))
 			set_theme(name);
 	} else {
 		sw_assert_not_reached();
