@@ -102,7 +102,7 @@ static stringarray_t znc_commands = {
 };
 
 static void
-add_cmd(PTEXTBUF matches, const char *str)
+add_cmd(PTEXTBUF matches, CSTRING str)
 {
 	if (textBuf_size(matches) != 0) {
 		if ((errno = textBuf_ins_next(matches, textBuf_tail(matches),
@@ -114,25 +114,14 @@ add_cmd(PTEXTBUF matches, const char *str)
 	}
 }
 
-static bool
-got_hits(const char *search_var)
-{
-	for (size_t i = 0; i < ARRAY_SIZE(znc_commands); i++) {
-		if (!strncmp(search_var, znc_commands[i], strlen(search_var)))
-			return true;
-	}
-
-	return false;
-}
-
 /*
  * usage: /znc [*module] <command>
  */
 void
-cmd_znc(const char *data)
+cmd_znc(CSTRING data)
 {
+	STRING			 dcopy;
 	bool			 written_linefeed = false;
-	char			*dcopy;
 	static chararray_t	 cmd = "/znc";
 
 	if (strings_match(data, "")) {
@@ -146,7 +135,7 @@ cmd_znc(const char *data)
 	free(dcopy);
 
 	try {
-		char				*module;
+		STRING				 module;
 		std::string			 token;
 		std::vector<std::string>	 tokens;
 
@@ -180,21 +169,21 @@ cmd_znc(const char *data)
 }
 
 PTEXTBUF
-get_list_of_matching_znc_commands(const char *search_var)
+get_list_of_matching_znc_commands(CSTRING search_var)
 {
-	PTEXTBUF	matches;
-
-	if (!got_hits(search_var))
-		return NULL;
-
-	matches = textBuf_new();
+	PTEXTBUF matches = textBuf_new();
 
 	for (size_t i = 0; i < ARRAY_SIZE(znc_commands); i++) {
-		const char *cmd = znc_commands[i];
+		CSTRING cmd = znc_commands[i];
 
 		if (!strncmp(search_var, cmd, strlen(search_var)))
 			add_cmd(matches, cmd);
 	}
 
+	if (textBuf_size(matches) == 0) {
+		textBuf_destroy(matches);
+		return NULL;
+	}
+
 	return matches;
 }
