@@ -1,15 +1,26 @@
 #ifndef DATA_CLASSIFY_H
 #define DATA_CLASSIFY_H
 
+typedef struct tagRANGE {
+	wchar_t start;
+	wchar_t stop;
+	CSTRING comment;
+} RANGE, *PRANGE;
+
 __SWIRC_BEGIN_DECLS
 bool	is_alphabetic(const char *);
-bool	is_numeric(const char *);
-bool	is_whiteSpace(const char *);
+bool	is_cjk(const wchar_t);
+bool	is_combined(const wchar_t);
 bool	is_irc_channel(const char *);
-bool	is_valid_nickname(const char *);
-bool	is_valid_username(const char *);
-bool	is_valid_real_name(const char *);
+bool	is_numeric(const char *);
 bool	is_valid_hostname(const char *);
+bool	is_valid_nickname(const char *);
+bool	is_valid_real_name(const char *);
+bool	is_valid_username(const char *);
+bool	is_whitespace(const char *);
+
+int	xwcwidth(const wchar_t, const int);
+int	xwcswidth(const wchar_t *, const int) NONNULL;
 __SWIRC_END_DECLS
 
 /* Inline function definitions
@@ -31,6 +42,21 @@ isEmpty(const char *data)
 	return (*data == '\0');
 }
 
+#ifndef _lint
+static SW_INLINE bool
+isValid(const void *ptr)
+{
+#if defined(HAVE_ETEXT_SEGMENT)
+	extern char etext;
+	return (ptr != NULL && ((const char *) ptr) > &etext);
+#else
+	return (ptr != NULL);
+#endif
+}
+#else
+#define isValid(_ptr) ((_ptr) != NULL)
+#endif
+
 #include <ctype.h>
 #include <limits.h>
 #include <stdio.h>		/* EOF */
