@@ -89,7 +89,8 @@ event_chan_hp(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_status_window, TYPE_SPEC1_WARN,
 		    true);
-		printtext(&ctx, "event_chan_hp: error: %s", e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+		    e.what());
 	}
 }
 
@@ -103,23 +104,23 @@ event_join(struct irc_message_compo *compo)
 	PRINTTEXT_CONTEXT	ctx;
 
 	try {
-		char	*nick, *user, *host;
-		char	*prefix = NULL;
-		char	*state = const_cast<char *>("");
+		CSTRING nick, user, host;
+		STRING prefix = NULL;
+		STRING state = const_cast<STRING>("");
 
 		if (compo == NULL)
 			throw std::runtime_error("no components");
 		else if (compo->prefix == NULL)
 			throw std::runtime_error("no prefix");
 
-		prefix = & (compo->prefix[1]);
+		prefix = &compo->prefix[1];
 
 		if ((nick = strtok_r(prefix, "!@", &state)) == NULL)
 			throw std::runtime_error("no nickname");
 		if ((user = strtok_r(NULL, "!@", &state)) == NULL)
-			user = const_cast<char *>("<no user>");
+			user = "<no user>";
 		if ((host = strtok_r(NULL, "!@", &state)) == NULL)
-			host = const_cast<char *>("<no host>");
+			host = "<no host>";
 
 		const char * const channel = (*(compo->params) == ':' ?
 		    &compo->params[1] : &compo->params[0]);
@@ -158,7 +159,8 @@ event_join(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_active_window,
 		    TYPE_SPEC1_FAILURE, true);
-		printtext(&ctx, "event_join: fatal: %s", e.what());
+		printtext(&ctx, "%s(%s): fatal: %s", __func__, compo->command,
+		    e.what());
 #if SHUTDOWN_IRC_CONNECTION_BEHAVIOR
 		printtext(&ctx, "Shutting down IRC connection...");
 		g_on_air = false;
@@ -176,29 +178,28 @@ event_kick(struct irc_message_compo *compo)
 	PRINTTEXT_CONTEXT	ctx;
 
 	try {
-		char	*channel, *victim, *reason;
-		char	*nick, *user, *host;
-		char	*prefix = NULL;
-		char	*state1 = const_cast<char *>("");
-		char	*state2 = const_cast<char *>("");
+		CSTRING channel, victim, reason;
+		CSTRING nick, user, host;
+		STRING prefix = NULL;
+		STRING state1 = const_cast<STRING>("");
+		STRING state2 = const_cast<STRING>("");
 
 		if (compo == NULL)
 			throw std::runtime_error("no components");
 		else if (compo->prefix == NULL)
 			throw std::runtime_error("no prefix");
 
-		prefix = & (compo->prefix[1]);
+		prefix = &compo->prefix[1];
 
 		if ((nick = strtok_r(prefix, "!@", &state1)) == NULL)
 			throw std::runtime_error("no nickname");
 		if ((user = strtok_r(NULL, "!@", &state1)) == NULL)
-			user = const_cast<char *>("<no user>");
+			user = "<no user>";
 		if ((host = strtok_r(NULL, "!@", &state1)) == NULL)
-			host = const_cast<char *>("<no host>");
+			host = "<no host>";
 
-		/* unused */
-		(void) user;
-		(void) host;
+		UNUSED_VAR(user);
+		UNUSED_VAR(host);
 
 		(void) strFeed(compo->params, 2);
 
@@ -239,7 +240,8 @@ event_kick(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_active_window,
 		    TYPE_SPEC1_FAILURE, true);
-		printtext(&ctx, "event_kick: fatal: %s", e.what());
+		printtext(&ctx, "%s(%s): fatal: %s", __func__, compo->command,
+		    e.what());
 #if SHUTDOWN_IRC_CONNECTION_BEHAVIOR
 		printtext(&ctx, "Shutting down IRC connection...");
 		g_on_air = false;
@@ -261,11 +263,11 @@ chg_status_for_owner(plus_minus_state_t pm_state, const char *nick,
 	switch (pm_state) {
 	case STATE_PLUS:
 		if (names_htbl_modify::owner(nick, channel, true) != OK)
-			err_log(0, "chg_status_for_owner (+)");
+			err_log(0, "%s (+)", __func__);
 		break;
 	case STATE_MINUS:
 		if (names_htbl_modify::owner(nick, channel, false) != OK)
-			err_log(0, "chg_status_for_owner (-)");
+			err_log(0, "%s (-)", __func__);
 		break;
 	case STATE_NEITHER_PM:
 	default:
@@ -281,11 +283,11 @@ chg_status_for_superop(plus_minus_state_t pm_state, const char *nick,
 	switch (pm_state) {
 	case STATE_PLUS:
 		if (names_htbl_modify::superop(nick, channel, true) != OK)
-			err_log(0, "chg_status_for_superop (+)");
+			err_log(0, "%s (+)", __func__);
 		break;
 	case STATE_MINUS:
 		if (names_htbl_modify::superop(nick, channel, false) != OK)
-			err_log(0, "chg_status_for_superop (-)");
+			err_log(0, "%s (-)", __func__);
 		break;
 	case STATE_NEITHER_PM:
 	default:
@@ -301,11 +303,11 @@ chg_status_for_op(plus_minus_state_t pm_state, const char *nick,
 	switch (pm_state) {
 	case STATE_PLUS:
 		if (names_htbl_modify::op(nick, channel, true) != OK)
-			err_log(0, "chg_status_for_op (+)");
+			err_log(0, "%s (+)", __func__);
 		break;
 	case STATE_MINUS:
 		if (names_htbl_modify::op(nick, channel, false) != OK)
-			err_log(0, "chg_status_for_op (-)");
+			err_log(0, "%s (-)", __func__);
 		break;
 	case STATE_NEITHER_PM:
 	default:
@@ -321,11 +323,11 @@ chg_status_for_halfop(plus_minus_state_t pm_state, const char *nick,
 	switch (pm_state) {
 	case STATE_PLUS:
 		if (names_htbl_modify::halfop(nick, channel, true) != OK)
-			err_log(0, "chg_status_for_halfop (+)");
+			err_log(0, "%s (+)", __func__);
 		break;
 	case STATE_MINUS:
 		if (names_htbl_modify::halfop(nick, channel, false) != OK)
-			err_log(0, "chg_status_for_halfop (-)");
+			err_log(0, "%s (-)", __func__);
 		break;
 	case STATE_NEITHER_PM:
 	default:
@@ -341,11 +343,11 @@ chg_status_for_voice(plus_minus_state_t pm_state, const char *nick,
 	switch (pm_state) {
 	case STATE_PLUS:
 		if (names_htbl_modify::voice(nick, channel, true) != OK)
-			err_log(0, "chg_status_for_voice (+)");
+			err_log(0, "%s (+)", __func__);
 		break;
 	case STATE_MINUS:
 		if (names_htbl_modify::voice(nick, channel, false) != OK)
-			err_log(0, "chg_status_for_voice (-)");
+			err_log(0, "%s (-)", __func__);
 		break;
 	case STATE_NEITHER_PM:
 	default:
@@ -364,24 +366,24 @@ static void
 maintain_channel_stats(const char *channel, const char *input)
 {
 	char			*input_copy;
-	char			*modes = const_cast<char *>("");
 	char			*nicks[15] = { NULL };
 	char			*state = const_cast<char *>("");
-	const size_t		 ar_sz = ARRAY_SIZE(nicks);
+	const char		*modes = "";
 	plus_minus_state_t	 pm_state = STATE_NEITHER_PM;
 	size_t			 ar_i = 0;
 	size_t			 nicks_assigned = 0;
+	static const size_t	 ar_sz = ARRAY_SIZE(nicks);
 
 	input_copy = sw_strdup(input);
 
 	if ((modes = strtok_r(input_copy, " ", &state)) == NULL) {
-		err_log(EINVAL, "maintain_channel_stats");
+		err_log(EINVAL, "%s", __func__);
 		free(input_copy);
 		return;
 	}
 
 	for (nicks_assigned = 0;; nicks_assigned++) {
-		char	*token;
+		const char	*token;
 
 		if ((token = strtok_r(NULL, " ", &state)) != NULL &&
 		    nicks_assigned < ar_sz)
@@ -390,7 +392,7 @@ maintain_channel_stats(const char *channel, const char *input)
 			break;
 	}
 
-	for (char *cp = modes; *cp && ar_i < nicks_assigned; cp++) {
+	for (const char *cp = modes; *cp && ar_i < nicks_assigned; cp++) {
 		switch (*cp) {
 		case '+':
 			pm_state = STATE_PLUS;
@@ -429,7 +431,7 @@ maintain_channel_stats(const char *channel, const char *input)
 
 	if (strspn(modes, "+-Ibeqaohv") != strlen(modes) && net_send("MODE %s",
 	    channel) < 0)
-		err_log(ENOTCONN, "maintain_channel_stats: net_send");
+		err_log(ENOTCONN, "%s: net_send", __func__);
 
 	free(input_copy);
 
@@ -454,17 +456,17 @@ event_mode(struct irc_message_compo *compo)
 	char *next_token_copy = NULL;
 
 	try {
-		char	*channel, *next_token;
-		char	*cp = NULL;
-		char	*nick = NULL;
-		char	*prefix = NULL;
-		char	*state1 = const_cast<char *>("");
-		char	*state2 = const_cast<char *>("");
+		char		*channel, *next_token;
+		char		*cp = NULL;
+		char		*prefix = NULL;
+		char		*state1 = const_cast<char *>("");
+		char		*state2 = const_cast<char *>("");
+		const char	*nick, *user, *host;
 
 		if (compo->prefix == NULL)
 			throw std::runtime_error("no prefix");
 
-		prefix = & (compo->prefix[1]);
+		prefix = &compo->prefix[1];
 
 		if ((nick = strtok_r(prefix, "!@", &state1)) == NULL) {
 			throw std::runtime_error("unable to get nickname in "
@@ -473,6 +475,13 @@ event_mode(struct irc_message_compo *compo)
 			throw std::runtime_error("strFeed");
 		}
 
+		if ((user = strtok_r(NULL, "!@", &state1)) == NULL)
+			user = "";
+		if ((host = strtok_r(NULL, "!@", &state1)) == NULL)
+			host = "";
+		UNUSED_VAR(user);
+		UNUSED_VAR(host);
+
 		if ((channel = strtok_r(compo->params, "\n", &state2)) == NULL ||
 		    (next_token = strtok_r(NULL, "\n", &state2)) == NULL) {
 			throw std::runtime_error("insufficient data");
@@ -488,16 +497,16 @@ event_mode(struct irc_message_compo *compo)
 
 		printtext_context_init(&ctx, g_status_window, TYPE_SPEC1, true);
 
-		if (strings_match_ignore_case(nick, channel)) {
+		if (strings_match_ignore_case(channel, g_my_nickname)) {
 			/*
 			 * User mode
 			 */
 
 			printtext(&ctx, _("Mode change %s%s%s for user %c%s%c"),
 			    LEFT_BRKT, next_token_copy, RIGHT_BRKT,
-			    BOLD, nick, BOLD);
+			    BOLD, g_my_nickname, BOLD);
 
-			if (net_send("MODE %s", nick) < 0)
+			if (net_send("MODE %s", g_my_nickname) < 0)
 				throw std::runtime_error("cannot send");
 		} else if (is_irc_channel(channel) &&
 		    (ctx.window = window_by_label(channel)) != NULL) {
@@ -507,17 +516,14 @@ event_mode(struct irc_message_compo *compo)
 			    COLOR2, nick, NORMAL);
 
 			maintain_channel_stats(channel, next_token_copy);
-		} else if (strings_match_ignore_case(nick, "NickServ") &&
-		    strings_match_ignore_case(channel, g_my_nickname)) {
-			if (net_send("MODE %s", g_my_nickname) < 0)
-				throw std::runtime_error("cannot send");
 		} else {
 			throw std::runtime_error("unhandled else branch");
 		}
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_status_window, TYPE_SPEC1_WARN,
 		    true);
-		printtext(&ctx, "event_mode: error: %s", e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+		    e.what());
 	}
 
 	free(next_token_copy);
@@ -540,10 +546,10 @@ RemoveAndInsertNick(const char *old_nick, const char *new_nick,
 	is_voice	= p->is_voice;
 
 	if (event_names_htbl_remove(old_nick, label) != OK) {
-		err_log(0, "RemoveAndInsertNick: event_names_htbl_remove");
+		err_log(0, "%s: event_names_htbl_remove", __func__);
 		return ERR;
 	} else if (event_names_htbl_insert(new_nick, label) != OK) {
-		err_log(0, "RemoveAndInsertNick: event_names_htbl_insert");
+		err_log(0, "%s: event_names_htbl_insert", __func__);
 		return ERR;
 	}
 
@@ -573,27 +579,27 @@ event_nick(struct irc_message_compo *compo)
 	PRINTTEXT_CONTEXT	ctx;
 
 	try {
-		char	*new_nick;
-		char	*nick, *user, *host;
-		char	*prefix = NULL;
-		char	*state = const_cast<char *>("");
+		CSTRING new_nick;
+		CSTRING nick, user, host;
+		STRING prefix = NULL;
+		STRING state = const_cast<STRING>("");
 
 		if (compo->prefix == NULL)
 			throw std::runtime_error("no prefix");
 
 		new_nick = (*(compo->params) == ':' ? &compo->params[1] :
 		    &compo->params[0]);
-		prefix = & (compo->prefix[1]);
+		prefix = &compo->prefix[1];
 
 		if ((nick = strtok_r(prefix, "!@", &state)) == NULL)
 			throw std::runtime_error("no nickname");
 
-		user = strtok_r(NULL, "!@", &state);
-		host = strtok_r(NULL, "!@", &state);
-
-		/* unused */
-		(void) user;
-		(void) host;
+		if ((user = strtok_r(NULL, "!@", &state)) == NULL)
+			user = "";
+		if ((host = strtok_r(NULL, "!@", &state)) == NULL)
+			host = "";
+		UNUSED_VAR(user);
+		UNUSED_VAR(host);
 
 		printtext_context_init(&ctx, NULL, TYPE_SPEC1_SPEC2, true);
 
@@ -617,7 +623,8 @@ event_nick(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_status_window, TYPE_SPEC1_WARN,
 		    true);
-		printtext(&ctx, "event_nick: error: %s", e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+		    e.what());
 	}
 }
 
@@ -632,23 +639,23 @@ event_part(struct irc_message_compo *compo)
 	PRINTTEXT_CONTEXT	ctx;
 
 	try {
-		char	*channel, *message;
-		char	*nick, *user, *host;
-		char	*prefix = NULL;
-		char	*state1 = const_cast<char *>("");
-		char	*state2 = const_cast<char *>("");
+		char		*prefix = NULL;
+		char		*state1 = const_cast<char *>("");
+		char		*state2 = const_cast<char *>("");
+		const char	*channel, *message;
+		const char	*nick, *user, *host;
 
 		if (compo->prefix == NULL)
 			throw std::runtime_error("no prefix!");
 
-		prefix = & (compo->prefix[1]);
+		prefix = &compo->prefix[1];
 
 		if ((nick = strtok_r(prefix, "!@", &state1)) == NULL)
 			throw std::runtime_error("unable to get nickname");
 		if ((user = strtok_r(NULL, "!@", &state1)) == NULL)
-			user = const_cast<char *>("<no user>");
+			user = "<no user>";
 		if ((host = strtok_r(NULL, "!@", &state1)) == NULL)
-			host = const_cast<char *>("<no host>");
+			host = "<no host>";
 
 		const bool has_message = strFeed(compo->params, 1) == 1;
 
@@ -680,7 +687,7 @@ event_part(struct irc_message_compo *compo)
 			if ((ctx.window = window_by_label(channel)) == NULL)
 				throw std::runtime_error("window lookup error");
 			if (!has_message || message == NULL)
-				message = const_cast<char *>("");
+				message = "";
 			if (has_message && message != NULL && *message == ':')
 				message++;
 
@@ -694,7 +701,8 @@ event_part(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_active_window,
 		    TYPE_SPEC1_FAILURE, true);
-		printtext(&ctx, "event_part: fatal: %s", e.what());
+		printtext(&ctx, "%s(%s): fatal: %s", __func__, compo->command,
+		    e.what());
 #if SHUTDOWN_IRC_CONNECTION_BEHAVIOR
 		printtext(&ctx, "Shutting down IRC connection...");
 		g_on_air = false;
@@ -712,24 +720,24 @@ event_quit(struct irc_message_compo *compo)
 	PRINTTEXT_CONTEXT	ctx;
 
 	try {
-		char	*message;
-		char	*nick, *user, *host;
-		char	*prefix;
-		char	*state = const_cast<char *>("");
+		CSTRING message;
+		CSTRING nick, user, host;
+		STRING prefix;
+		STRING state = const_cast<STRING>("");
 
 		if (compo->prefix == NULL)
 			throw std::runtime_error("no prefix");
 
 		message = (*(compo->params) == ':' ? &compo->params[1] :
 		    &compo->params[0]);
-		prefix = & (compo->prefix[1]);
+		prefix = &compo->prefix[1];
 
 		if ((nick = strtok_r(prefix, "!@", &state)) == NULL)
 			throw std::runtime_error("unable to get nickname");
 		if ((user = strtok_r(NULL, "!@", &state)) == NULL)
-			user = const_cast<char *>("<no user>");
+			user = "<no user>";
 		if ((host = strtok_r(NULL, "!@", &state)) == NULL)
-			host = const_cast<char *>("<no host>");
+			host = "<no host>";
 
 		printtext_context_init(&ctx, NULL, TYPE_SPEC1_SPEC2, true);
 
@@ -754,7 +762,8 @@ event_quit(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_status_window, TYPE_SPEC1_WARN,
 		    true);
-		printtext(&ctx, "event_quit: error: %s", e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+		    e.what());
 	}
 }
 
@@ -796,7 +805,8 @@ event_topic(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_status_window, TYPE_SPEC1_WARN,
 		    true);
-		printtext(&ctx, "event_topic: error: %s", e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+		    e.what());
 	}
 }
 
@@ -810,26 +820,26 @@ event_topic_chg(struct irc_message_compo *compo)
 	PRINTTEXT_CONTEXT	ctx;
 
 	try {
-		char	*channel, *new_topic;
-		char	*nick, *user, *host;
-		char	*prefix = NULL;
-		char	*state1 = const_cast<char *>("");
-		char	*state2 = const_cast<char *>("");
+		char		*prefix = NULL;
+		char		*state1 = const_cast<char *>("");
+		char		*state2 = const_cast<char *>("");
+		const char	*channel, *new_topic;
+		const char	*nick, *user, *host;
 
 		if (compo->prefix == NULL)
 			throw std::runtime_error("no prefix");
 
-		prefix = & (compo->prefix[1]);
+		prefix = &compo->prefix[1];
 
 		if ((nick = strtok_r(prefix, "!@", &state1)) == NULL)
 			throw std::runtime_error("no nickname");
 
-		user = strtok_r(NULL, "!@", &state1);
-		host = strtok_r(NULL, "!@", &state1);
-
-		/* unused */
-		(void) user;
-		(void) host;
+		if ((user = strtok_r(NULL, "!@", &state1)) == NULL)
+			user = "";
+		if ((host = strtok_r(NULL, "!@", &state1)) == NULL)
+			host = "";
+		UNUSED_VAR(user);
+		UNUSED_VAR(host);
 
 		if (strFeed(compo->params, 1) != 1)
 			throw std::runtime_error("strFeed");
@@ -854,7 +864,8 @@ event_topic_chg(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_status_window, TYPE_SPEC1_WARN,
 		    true);
-		printtext(&ctx, "event_topic_chg: error: %s", e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+		    e.what());
 	}
 }
 
@@ -870,11 +881,11 @@ event_topic_creator(struct irc_message_compo *compo)
 	char *string_copy = NULL;
 
 	try {
-		char		*channel, *creator, *time_str;
-		char		*nick, *user, *host;
+		char		 tbuf[100] = { '\0' };
 		char		*state1 = const_cast<char *>("");
 		char		*state2 = const_cast<char *>("");
-		char		 tbuf[100] = { '\0' };
+		const char	*channel, *creator, *time_str;
+		const char	*nick, *user, *host;
 		struct tm	 result = { 0 };
 
 		if (strFeed(compo->params, 3) != 3)
@@ -932,7 +943,8 @@ event_topic_creator(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ctx, g_status_window, TYPE_SPEC1_WARN,
 		    true);
-		printtext(&ctx, "event_topic_creator: error: %s", e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+		    e.what());
 	}
 
 	free(string_copy);
