@@ -227,11 +227,11 @@ event_notice(struct irc_message_compo *compo)
 	} catch (const std::runtime_error &e) {
 		printtext_context_init(&ptext_ctx, g_status_window,
 		    TYPE_SPEC1_WARN, true);
-		printtext(&ptext_ctx, "event_notice: error: %s", e.what());
+		printtext(&ptext_ctx, "%s: error: %s", __func__, e.what());
 	} catch (const std::bad_alloc &e) {
-		err_exit(ENOMEM, "event_notice: error: %s", e.what());
+		err_exit(ENOMEM, "%s: error: %s", __func__, e.what());
 	} catch (...) {
-		err_log(0, "event_notice: error: unknown exception");
+		err_log(0, "%s: error: unknown exception", __func__);
 	}
 }
 
