@@ -40,6 +40,15 @@ typedef const char *usage_t[];
  * Run esc+q on the text from the outside of the array
  */
 
+static usage_t admin_usage = {
+  N_("usage: /admin [target]"),
+  "",
+  N_("The admin command is used to find information about the administrator\n"
+     "of the given server, or current server if 'target' parameter is omit-\n"
+     "ted."),
+  "",
+};
+
 static usage_t away_usage = {
   N_("usage: /away [reason]"),
   "",
@@ -170,6 +179,14 @@ static usage_t deop_usage = {
   "",
 };
 
+static usage_t die_usage = {
+  N_("usage: /die [--I-am-sure]"),
+  "",
+  N_("An IRC operator can use this command to shutdown the server. Please\n"
+     "confirm that this is what you really want by typing '--I-am-sure'."),
+  "",
+};
+
 static usage_t disconnect_usage = {
   N_("usage: /disconnect [message]"),
   "",
@@ -214,6 +231,23 @@ static usage_t fetchdic_usage = {
   "",
 };
 
+static usage_t gline_usage = {
+  N_("usage: /gline <nick!user@host> [<duration> :<reason>]"),
+  "",
+  N_("Network-wide bans."),
+  "",
+  N_("When a client matches a G-line it cannot connect to ANY server on the\n"
+     "IRC network for 'duration' seconds. If the duration is zero then the\n"
+     "G-line will be permanent."),
+  "",
+  N_("(If no duration and no reason is given the G-line is deleted.)"),
+  "",
+  (TXT_BOLD "SEE ALSO" TXT_BOLD),
+  "",
+  "    /kline",
+  "",
+};
+
 static usage_t group_usage = {
   N_("usage: /group <name>"),
   "",
@@ -268,6 +302,13 @@ static usage_t ilist_usage = {
   "",
 };
 
+static usage_t info_usage = {
+  N_("usage: /info [target]"),
+  "",
+  N_("The info command returns information about the server."),
+  "",
+};
+
 static usage_t invite_usage = {
   N_("usage: /invite <targ_nick> <channel>"),
   "",
@@ -275,6 +316,13 @@ static usage_t invite_usage = {
   "",
 };
 
+static usage_t ison_usage = {
+  N_("usage: /ison <nick1> [nick2] [nick3] [...]"),
+  "",
+  N_("Checks whether users are on IRC."),
+  "",
+};
+
 static usage_t join_usage = {
   N_("usage: /join <channel> [key]"),
   "",
@@ -316,6 +364,23 @@ static usage_t kill_usage = {
   "",
 };
 
+static usage_t kline_usage = {
+  N_("usage: /kline <nick!user@host> [<duration> :<reason>]"),
+  "",
+  N_("Server-local bans."),
+  "",
+  N_("When a client matches a K-line it cannot connect to the local server\n"
+     "for 'duration' seconds. If the duration is zero then the K-line will\n"
+     "be permanent."),
+  "",
+  N_("(If no duration and no reason is given the K-line is deleted.)"),
+  "",
+  (TXT_BOLD "SEE ALSO" TXT_BOLD),
+  "",
+  "    /gline",
+  "",
+};
+
 static usage_t list_usage = {
   N_("usage: /list [<max_users[,>min_users][,pattern][...]]"),
   "",
@@ -488,6 +553,15 @@ static usage_t quit_usage = {
   "",
 };
 
+static usage_t rehash_usage = {
+  N_("usage: /rehash"),
+  "",
+  N_("The rehash command is an administrative command which can be used by\n"
+     "an IRC operator to force the server to re-read and process its conf-\n"
+     "iguration file."),
+  "",
+};
+
 static usage_t resize_usage = {
   N_("usage: /resize"),
   "",
@@ -497,6 +571,14 @@ static usage_t resize_usage = {
   "",
 };
 
+static usage_t restart_usage = {
+  N_("usage: /restart [--I-am-sure]"),
+  "",
+  N_("An IRC operator can use the 'restart'-command to force the server to\n"
+     "restart itself."),
+  "",
+};
+
 #if NOT_YET
 static usage_t rgui_usage = {
   "usage: /rgui ...",
@@ -578,6 +660,13 @@ static usage_t servlist_usage = {
   "",
 };
 
+static usage_t servstats_usage = {
+  N_("usage: /servstats [<query> [<target>]]"),
+  "",
+  N_("This command is used to query statistics of a certain IRC server."),
+  "",
+};
+
 static usage_t set_usage = {
   N_("usage: /set [[setting] [value]]"),
   "",
@@ -694,6 +783,14 @@ static usage_t version_usage = {
   "",
 };
 
+static usage_t wallops_usage = {
+  N_("usage: /wallops <message>"),
+  "",
+  N_("The 'wallops'-command is used to send a message to all currently\n"
+     "connected users who have set the 'w' user mode for themselves."),
+  "",
+};
+
 static usage_t who_usage = {
   N_("usage: /who <mask>"),
   "",
