@@ -50,6 +50,7 @@
 #include "terminal.h"
 #include "theme.h"
 
+#include "commands/admin.h"
 #include "commands/ban.h"
 #include "commands/cap.h"
 #include "commands/cleartoasts.h"
@@ -58,6 +59,7 @@
 #include "commands/echo.h"
 #include "commands/fetchdic.h"
 #include "commands/ignore.h"
+#include "commands/info.h"
 #include "commands/invite.h"
 #include "commands/jp.h"
 #include "commands/kick.h"
@@ -95,6 +97,7 @@ static struct cmds_tag {
 	const size_t	 size;
 	bool		 irc_only;
 } cmds[] = {
+	{ "admin",       cmd_admin,       true,  admin_usage,       ARRAY_SIZE(admin_usage),       true  },
 	{ "away",        cmd_away,        true,  away_usage,        ARRAY_SIZE(away_usage),        true  },
 	{ "ban",         cmd_ban,         true,  ban_usage,         ARRAY_SIZE(ban_usage),         true  },
 	{ "banlist",     cmd_banlist,     true,  banlist_usage,     ARRAY_SIZE(banlist_usage),     true  },
@@ -109,20 +112,25 @@ static struct cmds_tag {
 	{ "cs",          cmd_chanserv,    true,  chanserv_usage,    ARRAY_SIZE(chanserv_usage),    true  },
 	{ "cycle",       cmd_cycle,       true,  cycle_usage,       ARRAY_SIZE(cycle_usage),       true  },
 	{ "deop",        cmd_deop,        true,  deop_usage,        ARRAY_SIZE(deop_usage),        true  },
+	{ "die",         cmd_die,         true,  die_usage,         ARRAY_SIZE(die_usage),         true  },
 	{ "disconnect",  cmd_disconnect,  false, disconnect_usage,  ARRAY_SIZE(disconnect_usage),  false },
 	{ "echo",        cmd_echo,        false, echo_usage,        ARRAY_SIZE(echo_usage),        false },
 	{ "exlist",      cmd_exlist,      true,  exlist_usage,      ARRAY_SIZE(exlist_usage),      true  },
 	{ "fetchdic",    cmd_fetchdic,    false, fetchdic_usage,    ARRAY_SIZE(fetchdic_usage),    false },
+	{ "gline",       cmd_gline,       true,  gline_usage,       ARRAY_SIZE(gline_usage),       true  },
 	{ "group",       cmd_group,       true,  group_usage,       ARRAY_SIZE(group_usage),       false },
 	{ "help",        cmd_help,        false, help_usage,        ARRAY_SIZE(help_usage),        false },
 	{ "ignore",      cmd_ignore,      false, ignore_usage,      ARRAY_SIZE(ignore_usage),      false },
 	{ "ilist",       cmd_ilist,       true,  ilist_usage,       ARRAY_SIZE(ilist_usage),       true  },
+	{ "info",        cmd_info,        true,  info_usage,        ARRAY_SIZE(info_usage),        true  },
 	{ "invite",      cmd_invite,      true,  invite_usage,      ARRAY_SIZE(invite_usage),      true  },
+	{ "ison",        cmd_ison,        true,  ison_usage,        ARRAY_SIZE(ison_usage),        true  },
 	{ "j",           cmd_join,        true,  join_usage,        ARRAY_SIZE(join_usage),        true  },
 	{ "join",        cmd_join,        true,  join_usage,        ARRAY_SIZE(join_usage),        true  },
 	{ "kick",        cmd_kick,        true,  kick_usage,        ARRAY_SIZE(kick_usage),        true  },
 	{ "kickban",     cmd_kickban,     true,  kickban_usage,     ARRAY_SIZE(kickban_usage),     true  },
 	{ "kill",        cmd_kill,        true,  kill_usage,        ARRAY_SIZE(kill_usage),        true  },
+	{ "kline",       cmd_kline,       true,  kline_usage,       ARRAY_SIZE(kline_usage),       true  },
 	{ "list",        cmd_list,        true,  list_usage,        ARRAY_SIZE(list_usage),        false },
 	{ "me",          cmd_me,          true,  me_usage,          ARRAY_SIZE(me_usage),          true  },
 	{ "mode",        cmd_mode,        true,  mode_usage,        ARRAY_SIZE(mode_usage),        true  },
@@ -139,7 +147,9 @@ static struct cmds_tag {
 	{ "qbot",        cmd_qbot,        true,  qbot_usage,        ARRAY_SIZE(qbot_usage),        true  },
 	{ "query",       cmd_query,       false, query_usage,       ARRAY_SIZE(query_usage),       false },
 	{ "quit",        cmd_quit,        false, quit_usage,        ARRAY_SIZE(quit_usage),        false },
+	{ "rehash",      cmd_rehash,      true,  rehash_usage,      ARRAY_SIZE(rehash_usage),      true  },
 	{ "resize",      cmd_resize,      false, resize_usage,      ARRAY_SIZE(resize_usage),      false },
+	{ "restart",     cmd_restart,     true,  restart_usage,     ARRAY_SIZE(restart_usage),     true  },
 #if NOT_YET
 	{ "rgui",        cmd_rgui,        false, rgui_usage,        ARRAY_SIZE(rgui_usage),        false },
 #endif
@@ -147,6 +157,7 @@ static struct cmds_tag {
 	{ "sasl",        cmd_sasl,        false, sasl_usage,        ARRAY_SIZE(sasl_usage),        true  },
 	{ "say",         cmd_say,         true,  say_usage,         ARRAY_SIZE(say_usage),         false },
 	{ "servlist",    cmd_servlist,    true,  servlist_usage,    ARRAY_SIZE(servlist_usage),    true  },
+	{ "servstats",   cmd_servstats,   true,  servstats_usage,   ARRAY_SIZE(servstats_usage),   true  },
 	{ "set",         cmd_set,         false, set_usage,         ARRAY_SIZE(set_usage),         false },
 	{ "squery",      cmd_squery,      true,  squery_usage,      ARRAY_SIZE(squery_usage),      true  },
 	{ "stats",       cmd_stats,       true,  stats_usage,       ARRAY_SIZE(stats_usage),       false },
@@ -156,6 +167,7 @@ static struct cmds_tag {
 	{ "unban",       cmd_unban,       true,  unban_usage,       ARRAY_SIZE(unban_usage),       true  },
 	{ "unignore",    cmd_unignore,    false, unignore_usage,    ARRAY_SIZE(unignore_usage),    false },
 	{ "version",     cmd_version,     true,  version_usage,     ARRAY_SIZE(version_usage),     true  },
+	{ "wallops",     cmd_wallops,     true,  wallops_usage,     ARRAY_SIZE(wallops_usage),     true  },
 	{ "who",         cmd_who,         true,  who_usage,         ARRAY_SIZE(who_usage),         true  },
 	{ "whois",       cmd_whois,       true,  whois_usage,       ARRAY_SIZE(whois_usage),       true  },
 	{ "znc",         cmd_znc,         true,  znc_usage,         ARRAY_SIZE(znc_usage),         true  },
