@@ -1,5 +1,5 @@
 /* libUtils.c  --  Library Utilities
-   Copyright (C) 2012-2022 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2023 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -357,12 +357,11 @@ fclose_ensure_success(FILE *fp)
 void
 realloc_strcat(char **dest, const char *src)
 {
-	size_t	newsize = 0;
+	size_t	newsize;
 
 	if (isNull(dest) || isNull(*dest) || isNull(src))
 		err_exit(EINVAL, "%s", __func__);
-	else
-		newsize = strlen(*dest) + strlen(src) + 1;
+	newsize = strlen(*dest) + strlen(src) + 1;
 
 	if ((*dest = realloc(*dest, newsize)) == NULL)
 		err_exit(ENOMEM, "%s", __func__);
