@@ -49,6 +49,24 @@ const char	g_log_filesuffix[] = ".txt";
 static const char *get_modified_server_host(const char *) NONNULL;
 static const char *get_logtype(const char *) NONNULL;
 
+static int
+check_label(const char *label, int *ip)
+{
+	static const char legal_index[] =
+	    "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+	    "abcdefghijklmnopqrstuvwxyz"
+	    "0123456789+-_";
+
+	for (const char *cp = &label[0]; *cp != '\0'; cp++) {
+		if (strchr(legal_index, *cp) == NULL) {
+			*ip = *cp;
+			return ERR;
+		}
+	}
+
+	return OK;
+}
+
 static const char *
 get_date(void)
 {
@@ -87,19 +105,48 @@ get_logtype(const char *label)
 {
 	if (strings_match_ignore_case(label, g_status_window_label))
 		return "1";
-	else if (is_irc_channel(label))
+	else if (!is_irc_channel(label))
 		return "2";
-	return "3";
+	else if (*label == '#')
+		return "3";
+	else if (*label == '&')
+		return "4";
+	else if (*label == '!')
+		return "5";
+	return "6";
 }
 
 char *
 log_get_path(const char *server_host, const char *label)
 {
-	char	*path;
+	char			*cp, *label_copy, *path;
+	int			 c = 'X';
+	size_t			 num_illegal = 0;
+	static const size_t	 maxlabel = 20;
 
 	if (server_host == NULL || label == NULL || g_log_dir == NULL)
 		return NULL;
 
+	label_copy = sw_strdup(label);
+
+	if (xstrnlen(label, maxlabel + 1) > maxlabel)
+		label_copy[maxlabel] = '\0';
+	while (check_label(label_copy, &c) != OK) {
+		if ((cp = strchr(label_copy, c)) == NULL)
+			sw_assert_not_reached();
+		*cp = 'X';
+		num_illegal++;
+	}
+	if (num_illegal && num_illegal == strlen(label_copy)) {
+		PRINTTEXT_CONTEXT	ctx;
+
+		printtext_context_init(&ctx, g_status_window,
+		    TYPE_SPEC1_FAILURE, true);
+		printtext(&ctx, "%s: inappropriate filename", __func__);
+		free(label_copy);
+		return NULL;
+	}
+
 	path = sw_strdup(g_log_dir);
 
 #if defined(UNIX)
@@ -111,7 +158,7 @@ log_get_path(const char *server_host, const char *label)
 	realloc_strcat(&path, get_modified_server_host(server_host));
 	realloc_strcat(&path, "-");
 	realloc_strcat(&path, get_logtype(label));
-	realloc_strcat(&path, ".");
+	realloc_strcat(&path, "-");
 
 	switch (atoi(get_logtype(label))) {
 	case 1:
@@ -119,12 +166,16 @@ log_get_path(const char *server_host, const char *label)
 		break;
 	case 2:
 	case 3:
-		realloc_strcat(&path, label);
+	case 4:
+	case 5:
+	case 6:
+		realloc_strcat(&path, label_copy);
 		break;
 	default:
 		sw_assert_not_reached();
 	}
 
+	free(label_copy);
 	realloc_strcat(&path, g_log_filesuffix);
 	return (strToLower(path));
 }
