@@ -73,7 +73,7 @@ char	*g_tmp_dir = NULL;
 char	*g_log_dir = NULL;
 
 const char	g_config_filesuffix[] = ".conf";
-const char	g_theme_filesuffix[] = ".the";
+const char	g_theme_filesuffix[] = ".thm";
 
 char	*g_config_file = NULL;
 char	*g_theme_file = NULL;
