@@ -45,8 +45,7 @@
 
 #include "events/cap.h" /* get_sasl_mechanism() */
 
-#define CAFILE	"trusted_roots.pem"
-#define CADIR	NULL
+char *g_ca_file = NULL;
 
 static SSL_CTX	*ssl_ctx = NULL;
 static SSL	*ssl = NULL;
@@ -279,6 +278,12 @@ net_ssl_check_hostname(const char *host, unsigned int flags)
 	return ret;
 }
 
+SSL *
+net_ssl_getobj(void)
+{
+	return ssl;
+}
+
 int
 net_ssl_send(const char *fmt, ...)
 {
@@ -447,7 +452,7 @@ net_ssl_init(void)
 
 	if (g_ssl_verify_peer && config_bool("ssl_verify_peer", true)) {
 #ifdef WIN32
-		if (!SSL_CTX_load_verify_locations(ssl_ctx, CAFILE, CADIR)) {
+		if (!SSL_CTX_load_verify_locations(ssl_ctx, g_ca_file, NULL)) {
 			printtext(&ptext_ctx, "%s: Error loading CA file "
 			    "and/or directory", __func__);
 		}
@@ -487,4 +492,6 @@ net_ssl_deinit(void)
 		SSL_CTX_free(ssl_ctx);
 		ssl_ctx = NULL;
 	}
+
+	free_and_null(&g_ca_file);
 }
