@@ -9,14 +9,14 @@
 class suggestion {
 public:
 	suggestion();
-	explicit suggestion(const char *);
+	explicit suggestion(CSTRING);
 	~suggestion();
 
-	const char	*get_word(void) const;
+	CSTRING		 get_word(void) const;
 	const wchar_t	*get_wide_word(void) const;
 
 private:
-	char		*word;
+	STRING		 word;
 	wchar_t		*wide_word;
 };
 
@@ -33,13 +33,13 @@ void	 spell_deinit(void);
 #ifdef __cplusplus
 void	 spell_destroy_suggs(std::vector<sugg_ptr> *);
 std::vector<sugg_ptr> *
-	 spell_get_suggs(const char *, const wchar_t *);
+	 spell_get_suggs(CSTRING, const wchar_t *);
 #endif
 
-void	 spell_test1(const char *);
+void	 spell_test1(CSTRING);
 void	 spell_test2(const wchar_t *);
 
-bool	 spell_word(const char *);
+bool	 spell_word(CSTRING);
 void	 spell_word_readline(volatile struct readline_session_context *);
 bool	 spell_wide_word(const wchar_t *);
 #endif // HAVE_HUNSPELL
